==> create-app-template-react-0.0.7.tgz: package/medlinker.config.js <==
const path = require('path');

module.exports = env => {
  const config = {};
  config.project = {};
  config.webpack = {};

  /**
   * 资源CDN地址
   */
  config.project.publicUrl = './';

  /**
   * rem 配置
   */
  config.project.rem = {
    enable: true,
  };

  /**
   * 预加载代码配置，修改后需要手动刷新浏览器
   */
  config.project.preload = {
    js: [path.resolve('./src/preload.js')],
  };

  /**
   * 启动页配置
   */
  config.project.splash = {
    // 是否启用
    enable: true,
    // 启动页配置
    config: {
      // 是否自动关闭，如果false，需要在代码中调用 `window.closeSplashScreen` 手动关闭
      autoClose: true,
      // 启动页样式css，可以覆盖默认样式，如背景色等
      style: '',
      // 启动页图片
      img: {
        src: './logo.png?v=1.1',
        width: '50%',
      },
    },
  };

  /**
   * sentry配置
   */
  config.project.sentry = {
    // 是否启用 sentry
    enable: true,
    config: {
      // dsn配置
      dsn: 'https://1cfcbb7d607e400ab233a8ef9661201d@sentry-int.medlinker.com/14',
      // 路径
      urlPrefix: ['/'],
    },
  };

  /**
   * growingio配置
   */
  config.project.growingio = {
    // 是否启用 growingio
    enable: false,
    config: {
      // growingio 的 key
      key: 'ad6251cfbfcc4d7c',
      // 是否启用 hash 路由
      hashtag: true,
      // debug 模式
      debug: false,
    },
  };

  /**
   * webpack devServer配置
   */
  config.webpack.devServer = {
    port: 3001,
    proxy: {
      '/api/**': {
        target: 'https://web.medlinker.com',
        changeOrigin: true,
        secure: false,
        pathRewrite: {
          '^/api': '',
        },
      },
    },
  };

  /**
   * webpack 插件配置
   */
  config.webpack.plugins = config => config;

  /**
   * postcss 插件配置
   */
  config.webpack.postcss = config => config;

  return config;
};

==> create-app-template-react-0.0.9.tgz: package/medlinker.config.js <==
const path = require('path');

module.exports = env => {
  const config = {};
  config.project = {};
  config.webpack = {};

  /**
   * 资源CDN地址
   */
  config.project.publicUrl = '';

  /**
   * rem 配置
   */
  config.project.rem = {
    enable: true,
  };

  /**
   * 预加载代码配置，修改后需要手动刷新浏览器
   */
  config.project.preload = {
    js: [path.resolve('./src/preload.js')],
  };

  /**
   * 启动页配置
   */
  config.project.splash = {
    // 是否启用
    enable: true,
    // 启动页配置
    config: {
      // 是否自动关闭，如果false，需要在代码中调用 `window.closeSplashScreen` 手动关闭
      autoClose: true,
      // 启动页样式css，可以覆盖默认样式，如背景色等
      style: '',
      // 启动页图片
      img: {
        src: './logo.png?v=1.1',
        width: '50%',
      },
    },
  };

  /**
   * sentry配置
   */
  config.project.sentry = {
    // 是否启用 sentry
    enable: true,
    config: {
      // dsn配置
      dsn: 'https://1cfcbb7d607e400ab233a8ef9661201d@sentry-int.medlinker.com/14',
      // 路径
      urlPrefix: ['/'],
    },
  };

  /**
   * growingio配置
   */
  config.project.growingio = {
    // 是否启用 growingio
    enable: false,
    config: {
      // growingio 的 key
      key: 'ad6251cfbfcc4d7c',
      // 是否启用 hash 路由
      hashtag: true,
      // debug 模式
      debug: false,
    },
  };

  /**
   * webpack devServer配置
   */
  config.webpack.devServer = {
    port: 3001,
    proxy: {
      '/api/**': {
        target: 'https://web.medlinker.com',
        changeOrigin: true,
        secure: false,
        pathRewrite: {
          '^/api': '',
        },
      },
    },
  };

  /**
   * webpack 插件配置
   */
  config.webpack.plugins = config => config;

  /**
   * postcss 插件配置
   */
  config.webpack.postcss = config => config;

  return config;
};
